@@ -105,60 +105,29 @@ setMethodS3("as.character", "DChipDcpSet", function(x, ...) {
 
 
 
-setMethodS3("findByName", "DChipDcpSet", function(static, name, tags=NULL, chipType=NULL, paths=c("rawData", "probeData"), ...) {
+setMethodS3("findByName", "DChipDcpSet", function(static, ..., paths=c("rawData/", "probeData/")) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Arguments 'name':
-  name <- Arguments$getCharacter(name, length=c(1,1));
-  if (nchar(name) == 0) {
-    throw("A ", class(static)[1], " must have a non-empty name: ''");
-  }
-
   # Arguments 'paths':
   if (is.null(paths)) {
     paths <- eval(formals(findByName.DChipDcpSet)[["paths"]]);
   }
 
 
-  # Look only in existing directories
-  paths <- sapply(paths, FUN=filePath, expandLinks="any");
-  paths0 <- paths;
-  paths <- paths[sapply(paths, FUN=isDirectory)];
-  if (length(paths) == 0) {
-    throw("None of the data directories exist: ", 
-                                           paste(paths0, collapse=", "));
-  }
-
-  # The full name of the data set
-  fullname <- paste(c(name, tags), collapse=",");
-
-  # Look for matching data sets
-  paths <- file.path(paths, fullname);
-  paths <- paths[sapply(paths, FUN=isDirectory)];
-  if (length(paths) == 0)
-    return(NULL);
-
-  # Look for matching chip type sets?
-  if (!is.null(chipType)) {
-    paths <- file.path(paths, chipType);
-    paths <- paths[sapply(paths, FUN=isDirectory)];
-    if (length(paths) == 0)
-      return(NULL);
-  }
-
-  if (length(paths) > 1) {
-    warning("Found duplicated data set: ", paste(paths, collapse=", "));
-    paths <- paths[1];
-  }
+  # Unfortunately method dispatching does not work here.
+  path <- findByName.AffymetrixCelSet(static, ..., paths=paths);
   
-  paths;
+  path;
 }, static=TRUE)
 
 
 setMethodS3("fromName", "DChipDcpSet", function(static, ...) {
-  byName(static, ...);
-}, static=TRUE)
+  className <- class(static)[1];
+  msg <- sprintf("%s$fromName() is defunct. Use %s$byName() instead.", 
+                                                className, className);
+  throw(msg);
+}, static=TRUE, deprecated=TRUE)
 
 
 setMethodS3("byName", "DChipDcpSet", function(static, name, tags=NULL, chipType, paths=NULL, ...) {
@@ -354,6 +323,9 @@ setMethodS3("extractTheta", "DChipDcpSet", function(this, units=NULL, ..., drop=
 
 ############################################################################
 # HISTORY:
+# 2009-08-12
+# o Now findByName() of DChipDcpSet utilizes ditto of AffymetrixCelSet, 
+#   because its code was identical to the latter.
 # 2008-08-20
 # o Added extractTheta().
 # 2008-07-21
